@@ -12,14 +12,19 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from supertokens_python.framework.django.django_request import DjangoRequest
-from supertokens_python.framework.django.django_response import DjangoResponse
+from __future__ import annotations
+
+from typing import TYPE_CHECKING
+
 from supertokens_python.framework.types import Framework
 
+if TYPE_CHECKING:
+    from django.http import HttpRequest
+
 
 class DjangoFramework(Framework):
-    def wrap_request(self, unwrapped):
-        return DjangoRequest(unwrapped)
 
-    def wrap_response(self, unwrapped):
-        return DjangoResponse(unwrapped)
+    def wrap_request(self, unwrapped: HttpRequest):
+        from supertokens_python.framework.django.django_request import \
+            DjangoRequest
+        return DjangoRequest(unwrapped)
