@@ -11,16 +11,19 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
+from __future__ import annotations
 
-from supertokens_python.framework.fastapi.fastapi_request import FastApiRequest
-from supertokens_python.framework.fastapi.fastapi_response import FastApiResponse
+from typing import TYPE_CHECKING
 
 from supertokens_python.framework.types import Framework
 
+if TYPE_CHECKING:
+    from fastapi import Request
+
 
 class FastapiFramework(Framework):
-    def wrap_request(self, unwrapped):
-        return FastApiRequest(unwrapped)
 
-    def wrap_response(self, unwrapped):
-        return FastApiResponse(unwrapped)
+    def wrap_request(self, unwrapped: Request):
+        from supertokens_python.framework.fastapi.fastapi_request import \
+            FastApiRequest
+        return FastApiRequest(unwrapped)
