@@ -12,15 +12,18 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 from __future__ import annotations
-from __future__ import annotations
-from typing import List
 
-from supertokens_python.recipe.emailpassword.exceptions import raise_form_field_exception
+from typing import Any, Dict, List, Union
 
-from supertokens_python.recipe.emailpassword.constants import FORM_FIELD_EMAIL_ID
-from supertokens_python.recipe.emailpassword.types import FormField, ErrorFormField, NormalisedFormField
-from supertokens_python.utils import find_first_occurrence_in_list
 from supertokens_python.exceptions import raise_bad_input_exception
+from supertokens_python.recipe.emailpassword.constants import \
+    FORM_FIELD_EMAIL_ID
+from supertokens_python.recipe.emailpassword.exceptions import \
+    raise_form_field_exception
+from supertokens_python.recipe.emailpassword.types import (ErrorFormField,
+                                                           FormField,
+                                                           NormalisedFormField)
+from supertokens_python.utils import find_first_occurrence_in_list
 
 
 async def validate_form_or_throw_error(inputs: List[FormField], config_form_fields: List[NormalisedFormField]):
@@ -30,7 +33,7 @@ async def validate_form_or_throw_error(inputs: List[FormField], config_form_fiel
             'Are you sending too many / too few formFields?')
 
     for field in config_form_fields:
-        input_field: FormField = find_first_occurrence_in_list(
+        input_field: Union[None, FormField] = find_first_occurrence_in_list(
             lambda x: x.id == field.id, inputs)
         if input_field is None or (
                 input_field.value == '' and not field.optional):
@@ -50,26 +53,26 @@ async def validate_form_or_throw_error(inputs: List[FormField], config_form_fiel
             validation_errors)
 
 
-async def validate_form_fields_or_throw_error(config_form_fields: List[NormalisedFormField], form_fields_raw: any) -> \
+async def validate_form_fields_or_throw_error(config_form_fields: List[NormalisedFormField], form_fields_raw: Any) -> \
         List[FormField]:
     if form_fields_raw is None:
         raise_bad_input_exception('Missing input param: formFields')
 
-    if not isinstance(form_fields_raw, list):
+    if not isinstance(form_fields_raw, List):
         raise_bad_input_exception('formFields must be an array')
 
     form_fields: List[FormField] = []
 
-    for current_form_field in form_fields_raw:
+    form_fields_list_raw: List[Dict[str, Any]] = form_fields_raw
+    for current_form_field in form_fields_list_raw:
         if 'id' not in current_form_field or not isinstance(current_form_field['id'],
                                                             str) or 'value' not in current_form_field:
             raise_bad_input_exception(
                 'All elements of formFields must contain an \'id\' and \'value\' field')
         value = current_form_field['value']
-        id = current_form_field['id']
-        if id == FORM_FIELD_EMAIL_ID:
+        if current_form_field['id'] == FORM_FIELD_EMAIL_ID:
             value = value.strip()
-        form_fields.append(FormField(id, value))
+        form_fields.append(FormField(current_form_field['id'], value))
 
     await validate_form_or_throw_error(form_fields, config_form_fields)
     return form_fields
