@@ -15,11 +15,11 @@ from __future__ import annotations
 
 from supertokens_python.recipe.emailverification.interfaces import (
     APIInterface, APIOptions)
+from supertokens_python.utils import send_200_response
 
 
 async def handle_generate_email_verify_token_api(api_implementation: APIInterface, api_options: APIOptions):
     if api_implementation.disable_generate_email_verify_token_post:
         return None
     result = await api_implementation.generate_email_verify_token_post(api_options, {})
-    api_options.response.set_json_content(result.to_json())
-    return api_options.response
+    return send_200_response(result.to_json(), api_options.response)
