@@ -14,6 +14,7 @@
 from supertokens_python.exceptions import raise_bad_input_exception
 from supertokens_python.recipe.passwordless.interfaces import (APIInterface,
                                                                APIOptions)
+from supertokens_python.utils import send_200_response
 
 
 async def email_exists(api_implementation: APIInterface, api_options: APIOptions):
@@ -25,6 +26,4 @@ async def email_exists(api_implementation: APIInterface, api_options: APIOptions
         raise_bad_input_exception('Please provide the email as a GET param')
 
     result = await api_implementation.email_exists_get(email, api_options, {})
-    api_options.response.set_json_content(result.to_json())
-
-    return api_options.response
+    return send_200_response(result.to_json(), api_options.response)
