@@ -14,6 +14,7 @@
 from supertokens_python.exceptions import raise_bad_input_exception
 from supertokens_python.recipe.passwordless.interfaces import (APIInterface,
                                                                APIOptions)
+from supertokens_python.utils import send_200_response
 
 
 async def resend_code(api_implementation: APIInterface, api_options: APIOptions):
@@ -34,6 +35,4 @@ async def resend_code(api_implementation: APIInterface, api_options: APIOptions)
     device_id = body['deviceId']
 
     result = await api_implementation.resend_code_post(device_id, pre_auth_session_id, api_options, {})
-    api_options.response.set_json_content(result.to_json())
-
-    return api_options.response
+    return send_200_response(result.to_json(), api_options.response)
