@@ -11,9 +11,9 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-from .facebook import Facebook
-from .github import Github
-from .apple import Apple
-from .google import Google
-from .google_workspaces import GoogleWorkspaces
-from .discord import Discord
+from .apple import Apple  # type: ignore
+from .discord import Discord  # type: ignore
+from .facebook import Facebook  # type: ignore
+from .github import Github  # type: ignore
+from .google import Google  # type: ignore
+from .google_workspaces import GoogleWorkspaces  # type: ignore
